package symantec.itools.multimedia;

import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.Event;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Panel;
import java.net.URL;
import java.util.Vector;

public class SlideShow extends Panel {
   private int imageIndex = 0;
   private ImageViewer imageViewer = new ImageViewer();
   private Vector urlList = new Vector();
   private Vector images = new Vector();
   private Vector descriptions = new Vector();

   public void display() {
      this.imageIndex = 0;

      try {
         this.images.setElementAt(((Component)this).getToolkit().getImage((URL)this.urlList.elementAt(0)), this.imageIndex);
         this.imageViewer.setImage((Image)this.images.elementAt(0));
         ((Container)this).add(this.imageViewer);
         this.repaint();
         ((Container)this).validate();
      } catch (Exception var1) {
         System.err.println("Error in SlideShow: Couldn't get image " + ((URL)this.urlList.elementAt(this.imageIndex)).toString());
      }
   }

   public int getNumberOfImages() {
      return this.urlList.size();
   }

   public int getCurrentImageIndex() {
      return this.imageIndex;
   }

   public int addImageAndDescription(URL var1, String var2) {
      this.urlList.addElement(var1);
      this.descriptions.addElement(var2);
      this.images.addElement((Object)null);
      int var3 = this.urlList.size() - 1;
      if (var3 == 0) {
         this.display();
      }

      return var3;
   }

   public URL getURL(int var1) {
      return (URL)this.urlList.elementAt(var1);
   }

   public String getDescription(int var1) {
      return (String)this.descriptions.elementAt(var1);
   }

   public void setDescription(int var1, String var2) {
      this.descriptions.setElementAt(var2, var1);
   }

   public boolean isAtLastImage() {
      return this.imageIndex == this.urlList.size() - 1;
   }

   public boolean isAtFirstImage() {
      return this.imageIndex == 0;
   }

   public int nextImage() {
      if (!this.isAtLastImage()) {
         ++this.imageIndex;
         int var1 = this.setImage(this.imageIndex);
         ((Component)this).getParent().deliverEvent(new Event(this, 1001, new Integer(this.imageIndex)));
         return var1;
      } else {
         return this.imageIndex;
      }
   }

   public int previousImage() {
      if (!this.isAtFirstImage()) {
         --this.imageIndex;
         int var1 = this.setImage(this.imageIndex);
         ((Component)this).getParent().deliverEvent(new Event(this, 1001, new Integer(this.imageIndex)));
         return var1;
      } else {
         return this.imageIndex;
      }
   }

   public int setImage(int var1) {
      if (var1 >= 0 && var1 < this.urlList.size()) {
         try {
            this.imageIndex = var1;
            if (this.images.elementAt(this.imageIndex) == null) {
               this.images.setElementAt(((Component)this).getToolkit().getImage((URL)this.urlList.elementAt(this.imageIndex)), this.imageIndex);
            }
         } catch (Exception var2) {
            System.err.println("Error in SlideShow: Couldn't get image " + ((URL)this.urlList.elementAt(this.imageIndex)).toString());
         }

         this.imageViewer.setImage((Image)this.images.elementAt(this.imageIndex));
      }

      this.repaint();
      return this.imageIndex;
   }

   public Dimension preferredSize() {
      Dimension var1 = this.imageViewer.preferredSize();
      return new Dimension(var1.width, var1.height);
   }

   public void repaint() {
      super.repaint();
      this.imageViewer.repaint();
   }

   public void update(Graphics var1) {
      ((Component)this).paint(var1);
   }

   public void setFirstImage(URL var1) {
      if (var1 == null) {
         this.imageViewer.setImage((Image)null);
         this.imageIndex = 0;
         this.urlList = new Vector();
         this.images = new Vector();
         this.descriptions = new Vector();
      } else if (this.urlList.size() != 0) {
         this.urlList.setElementAt(var1, 0);
         this.descriptions.setElementAt("", 0);
         this.images.setElementAt((Object)null, 0);
         this.setImage(0);
      } else {
         this.addImageAndDescription(var1, "");
      }
   }
}
